AsyncDeviceStream

Struct AsyncDeviceStream 

pub struct AsyncDeviceStream { /* private fields */ }
An async connected device stream for bidirectional communication.

Implementations

Source

impl AsyncDeviceStream

pub async fn connect( addr: SocketAddr, bus_id: u32, dev_id: &str, password: Option<&str>, ) -> Result<Self, ViiperError>

pub async fn send<T: DeviceInput>(&self, input: &T) -> Result<(), ViiperError>

Send a device input to the device.

pub async fn send_timeout<T: DeviceInput>( &self, input: &T, timeout: Duration, ) -> Result<(), ViiperError>

Send a device input to the device with a timeout.

Arguments
  • input - The device input to send
  • timeout - Timeout duration for the operation
pub fn on_output<F, Fut>(&mut self, callback: F) -> Result<(), ViiperError>
where F: Fn(Arc<Mutex<AsyncReadWrapper>>) -> Fut + Send + 'static, Fut: Future<Output = Result<()>> + Send + 'static,

Register a callback to receive device output asynchronously. The callback receives a shared reference to the read half and must read the exact number of bytes expected. The callback will be invoked repeatedly on a tokio task until it returns an error. Only one callback can be registered at a time.

pub fn on_disconnect<F>(&mut self, callback: F) -> Result<(), ViiperError>
where F: FnOnce() + Send + 'static,

pub async fn send_raw(&self, data: &[u8]) -> Result<(), ViiperError>

Send raw bytes to the device.

pub async fn read_raw(&self, buf: &mut [u8]) -> Result<usize, ViiperError>

Read raw bytes from the device.

pub async fn read_exact(&self, buf: &mut [u8]) -> Result<(), ViiperError>

Read exact number of bytes from the device.