ViiperClient

Struct ViiperClient 

pub struct ViiperClient { /* private fields */ }
VIIPER management API client (synchronous).

Implementations

Source

impl ViiperClient

pub fn new(host: impl Into<String>, port: u16) -> Self

Create a new VIIPER client connecting to the specified host and port.

pub fn bus_list(&self) -> Result<BusListResponse, ViiperError>

BusList: bus/list -> BusListResponse

pub fn bus_create( &self, uint32: Option<u32>, ) -> Result<BusCreateResponse, ViiperError>

BusCreate: bus/create -> BusCreateResponse

pub fn bus_remove( &self, uint32: Option<u32>, ) -> Result<BusRemoveResponse, ViiperError>

BusRemove: bus/remove -> BusRemoveResponse

pub fn bus_devices_list( &self, id: u32, ) -> Result<DevicesListResponse, ViiperError>

BusDevicesList: bus/{id}/list -> DevicesListResponse

pub fn bus_device_add( &self, id: u32, device_create_request: &DeviceCreateRequest, ) -> Result<Device, ViiperError>

BusDeviceAdd: bus/{id}/add -> Device

pub fn bus_device_remove( &self, id: u32, string: Option<&str>, ) -> Result<DeviceRemoveResponse, ViiperError>

BusDeviceRemove: bus/{id}/remove -> DeviceRemoveResponse

pub fn connect_device( &self, bus_id: u32, dev_id: &str, ) -> Result<DeviceStream, ViiperError>

Connect to a device stream for sending input and receiving output.