pub trait DeviceInput {
// Required method
fn to_bytes(&self) -> Vec<u8> ⓘ;
}Expand description
Trait for device input types that can be serialized to wire protocol bytes.
Input types represent data sent from the client to the device (client-to-server).