pub trait DeviceOutput: Sized {
// Required method
fn from_bytes(buf: &[u8]) -> Result<Self, ViiperError>;
}Expand description
Trait for device output types that can be deserialized from wire protocol bytes.
Output types represent data received from the device (server-to-client).
Required Methods
Sourcefn from_bytes(buf: &[u8]) -> Result<Self, ViiperError>
fn from_bytes(buf: &[u8]) -> Result<Self, ViiperError>
Deserialize this output from wire protocol bytes (little-endian).
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.